--- a/review/extension_ui.py Sat Oct 10 19:07:59 2009 -0400
+++ b/review/extension_ui.py Sat Oct 10 19:10:44 2009 -0400
@@ -199,7 +199,26 @@
def review(ui, repo, *fnames, **opts):
- """code review a changeset in the current repository
+ """code review changesets in the current repository
+
+ To start using the review extension with a repository, you need to
+ initialize the code review data:
+
+ hg help review-init
+
+ Once you've initialized it (and cloned the review data repo to a
+ place where others can get to it), you can start reviewing changesets.
+
+ See the following help topics if you want to use the command-line
+ interface:
+
+ hg help review-review
+ hg help review-comment
+ hg help review-signoff
+
+ Once you've reviewed some changesets, don't forget to push your
+ comments and signoffs so other people can view them.
+
"""
if opts.pop('init'):
return _init_command(ui, repo, **opts)